@@ -178,6 +178,7 @@
 		       'int-vector?        (with-mock-wrapper #_int-vector?)
 		       'byte-vector?       (with-mock-wrapper #_byte-vector?)
 		       'float-vector?      (with-mock-wrapper #_float-vector?)
+		       'complex-vector?    (with-mock-wrapper #_complex-vector?)
 		       'length             (with-mock-wrapper #_length)
 		       'vector-append      (if (provided? 'pure-s7)
 					       (lambda args
@@ -615,59 +616,63 @@
 		 
  		 'make-polar       (if (provided? 'pure-s7)
  				       (lambda (mag ang) (#_complex (* mag (cos ang)) (* mag (sin ang))))
- 				       (lambda (mag ang) (#_make-polar (->value mag) (->value arg))))
+ 				       (lambda (mag ang) (#_make-polar (->value mag) (->value ang))))
 
-		 'make-rectangular (with-mock-wrapper* #_complex)
-		 'complex          (with-mock-wrapper* #_complex)
-		 'bignum           (with-mock-wrapper* #_bignum)
-		 'random-state     (with-mock-wrapper* #_random-state)
-		 'ash              (with-mock-wrapper* #_ash)
-		 'logbit?          (with-mock-wrapper* #_logbit?)
-		 'quotient         (with-mock-wrapper* #_quotient)
-		 'remainder        (with-mock-wrapper* #_remainder)
-		 'modulo           (with-mock-wrapper* #_modulo)
-		 'random           (with-mock-wrapper* #_random)
-		 'write-byte       (with-mock-wrapper* #_write-byte)
-		 'make-list        (with-mock-wrapper* #_make-list)
-		 'make-vector      (with-mock-wrapper* #_make-vector)
-		 'make-float-vector (with-mock-wrapper* #_make-float-vector)
-		 'make-int-vector  (with-mock-wrapper* #_make-int-vector)
-		 'make-byte-vector  (with-mock-wrapper* #_make-byte-vector)
-		 'make-hash-table  (with-mock-wrapper* #_make-hash-table)
-		 'object->string   (with-mock-wrapper* #_object->string)
-		 'format           (with-mock-wrapper* #_format)
-		 'write            (with-mock-wrapper* #_write)
-		 'display          (with-mock-wrapper* #_display)
-		 'string-fill!     (with-mock-wrapper* #_string-fill!)
-		 'copy             (with-mock-wrapper* #_copy)
-		 'vector->list     (with-mock-wrapper* #_vector->list)
-		 'string->list     (with-mock-wrapper* #_string->list)
-		 'substring        (with-mock-wrapper* #_substring)
-		 'vector-fill!     (with-mock-wrapper* #_vector-fill!)
-		 'fill!            (with-mock-wrapper* #_fill!)
-		 'make-string      (with-mock-wrapper* #_make-string)
-		 'string-ref       (with-mock-wrapper* #_string-ref)
-		 'string-set!      (with-mock-wrapper* #_string-set!)
-		 'string->number   (with-mock-wrapper* #_string->number)
-		 'list-ref         (with-mock-wrapper* #_list-ref)
-		 'list-set!        (with-mock-wrapper* #_list-set!)
-		 'list-tail        (with-mock-wrapper* #_list-tail)
-		 'vector-ref       (with-mock-wrapper* #_vector-ref)
-		 'float-vector-ref (with-mock-wrapper* #_float-vector-ref)
-		 'int-vector-ref   (with-mock-wrapper* #_int-vector-ref)
-		 'byte-vector-ref  (with-mock-wrapper* #_byte-vector-ref)
-		 'vector-set!      (with-mock-wrapper* #_vector-set!)
-		 'float-vector-set! (with-mock-wrapper* #_float-vector-set!)
-		 'int-vector-set!  (with-mock-wrapper* #_int-vector-set!)
-		 'byte-vector-set! (with-mock-wrapper* #_byte-vector-set!)
-		 'float-vector     (with-mock-wrapper* #_float-vector)
-		 'int-vector       (with-mock-wrapper* #_int-vector)
-		 'byte-vector      (with-mock-wrapper* #_byte-vector)
-		 'subvector        (with-mock-wrapper* #_subvector)
-		 'read-string      (with-mock-wrapper* #_read-string)
-		 'length           (with-mock-wrapper #_length)
-		 'c-pointer        (with-mock-wrapper #_c-pointer)
-		 'class-name       '*mock-number*)))
+		 'make-rectangular    (with-mock-wrapper* #_complex)
+		 'complex             (with-mock-wrapper* #_complex)
+		 'bignum              (with-mock-wrapper* #_bignum)
+		 'random-state        (with-mock-wrapper* #_random-state)
+		 'ash                 (with-mock-wrapper* #_ash)
+		 'logbit?             (with-mock-wrapper* #_logbit?)
+		 'quotient            (with-mock-wrapper* #_quotient)
+		 'remainder           (with-mock-wrapper* #_remainder)
+		 'modulo              (with-mock-wrapper* #_modulo)
+		 'random              (with-mock-wrapper* #_random)
+		 'write-byte          (with-mock-wrapper* #_write-byte)
+		 'make-list           (with-mock-wrapper* #_make-list)
+		 'make-vector         (with-mock-wrapper* #_make-vector)
+		 'make-complex-vector (with-mock-wrapper* #_make-complex-vector)
+		 'make-float-vector   (with-mock-wrapper* #_make-float-vector)
+		 'make-int-vector     (with-mock-wrapper* #_make-int-vector)
+		 'make-byte-vector    (with-mock-wrapper* #_make-byte-vector)
+		 'make-hash-table     (with-mock-wrapper* #_make-hash-table)
+		 'object->string      (with-mock-wrapper* #_object->string)
+		 'format              (with-mock-wrapper* #_format)
+		 'write               (with-mock-wrapper* #_write)
+		 'display             (with-mock-wrapper* #_display)
+		 'string-fill!        (with-mock-wrapper* #_string-fill!)
+		 'copy                (with-mock-wrapper* #_copy)
+		 'vector->list        (with-mock-wrapper* #_vector->list)
+		 'string->list        (with-mock-wrapper* #_string->list)
+		 'substring           (with-mock-wrapper* #_substring)
+		 'vector-fill!        (with-mock-wrapper* #_vector-fill!)
+		 'fill!               (with-mock-wrapper* #_fill!)
+		 'make-string         (with-mock-wrapper* #_make-string)
+		 'string-ref          (with-mock-wrapper* #_string-ref)
+		 'string-set!         (with-mock-wrapper* #_string-set!)
+		 'string->number      (with-mock-wrapper* #_string->number)
+		 'list-ref            (with-mock-wrapper* #_list-ref)
+		 'list-set!           (with-mock-wrapper* #_list-set!)
+		 'list-tail           (with-mock-wrapper* #_list-tail)
+		 'vector-ref          (with-mock-wrapper* #_vector-ref)
+		 'complex-vector-ref  (with-mock-wrapper* #_complex-vector-ref)
+		 'float-vector-ref    (with-mock-wrapper* #_float-vector-ref)
+		 'int-vector-ref      (with-mock-wrapper* #_int-vector-ref)
+		 'byte-vector-ref     (with-mock-wrapper* #_byte-vector-ref)
+		 'vector-set!         (with-mock-wrapper* #_vector-set!)
+		 'complex-vector-set! (with-mock-wrapper* #_complex-vector-set!)
+		 'float-vector-set!   (with-mock-wrapper* #_float-vector-set!)
+		 'int-vector-set!     (with-mock-wrapper* #_int-vector-set!)
+		 'byte-vector-set!    (with-mock-wrapper* #_byte-vector-set!)
+		 'complex-vector      (with-mock-wrapper* #_complex-vector)
+		 'float-vector        (with-mock-wrapper* #_float-vector)
+		 'int-vector          (with-mock-wrapper* #_int-vector)
+		 'byte-vector         (with-mock-wrapper* #_byte-vector)
+		 'subvector           (with-mock-wrapper* #_subvector)
+		 'read-string         (with-mock-wrapper* #_read-string)
+		 'length              (with-mock-wrapper #_length)
+		 'c-pointer           (with-mock-wrapper #_c-pointer)
+		 'class-name          '*mock-number*)))
 	  
 	  (define (mock-number x)
 	    (if (and (number? x)
@@ -1004,6 +1009,7 @@
 		       'write           (with-mock-wrapper* #_write)
 		       'display         (with-mock-wrapper* #_display)
 		       'fill!           (with-mock-wrapper* #_fill!)
+		       'class-name      '*mock-c-pointer*
 		       )))
 	  
 	  (define* (mock-c-pointer (int 0) type info weak1 weak2)
@@ -1034,6 +1040,7 @@
 		       'format             (with-mock-wrapper* #_format)
 		       'write              (with-mock-wrapper* #_write)
 		       'display            (with-mock-wrapper* #_display)
+		       'class-name         '*mock-random-state*
 		       )))
 	  
 	  (define* (mock-random-state seed (carry 1675393560))
@@ -1065,6 +1072,7 @@
 		       'format            (with-mock-wrapper* #_format)
 		       'write             (with-mock-wrapper* #_write)
 		       'display           (with-mock-wrapper* #_display)
+		       'class-name        '*mock-iterator*
 		       )))
 	  
 	  (define (make-mock-iterator . args)
